summaryrefslogtreecommitdiffstats
path: root/kdat/File.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kdat/File.cpp')
-rw-r--r--kdat/File.cpp16
1 files changed, 8 insertions, 8 deletions
diff --git a/kdat/File.cpp b/kdat/File.cpp
index ce05aeb..fd766b3 100644
--- a/kdat/File.cpp
+++ b/kdat/File.cpp
@@ -44,9 +44,9 @@ File::File( File* parent, FILE* fptr, int offset )
File::~File()
{
- while ( _tqchildren.first() ) {
- delete _tqchildren.first();
- _tqchildren.removeFirst();
+ while ( _children.first() ) {
+ delete _children.first();
+ _children.removeFirst();
}
}
@@ -164,7 +164,7 @@ void File::write( FILE* fptr )
fwrite( &ival, sizeof( ival ), 1, fptr );
}
// Number of immediate tqchildren (4 bytes).
ival = getChildren().count();
fwrite( &ival, sizeof( ival ), 1, fptr );
@@ -175,10 +175,10 @@ void File::write( FILE* fptr )
}
//===== Write files =====
- ival = _tqchildren.count();
+ ival = _children.count();
fwrite( &ival, sizeof( ival ), 1, fptr );
- TQPtrListIterator<File> i( _tqchildren );
+ TQPtrListIterator<File> i( _children );
int count = 0;
for ( ; i.current(); ++i, count++ ) {
// Fill in the file offset.
@@ -252,7 +252,7 @@ const TQPtrList<File>& File::getChildren()
{
read();
- return _tqchildren;
+ return _children;
}
const TQPtrList<Range>& File::getRanges()
@@ -266,7 +266,7 @@ void File::addChild( File* file )
{
read();
- _tqchildren.append( file );
+ _children.append( file );
}
void File::calcRanges()
@@ -164,7 +164,7 @@ void File::write( FILE* fptr )
fwrite( &ival, sizeof( ival ), 1, fptr );
}
- // Number of immediate tqchildren (4 bytes).
+ // Number of immediate children (4 bytes).
ival = getChildren().count();
fwrite( &ival, sizeof( ival ), 1, fptr );